<p align="center">
  <a href="https://babeljs.io/">
    <img alt="babel" src="https://raw.githubusercontent.com/babel/logo/master/logo.png" width="546">
  </a>
</p>

<p align="center">
  <strong>Babel</strong> is a transpiler for writing next generation JavaScript.
</p>

<p align="center">
  For questions and support please visit the <a href="https://gitter.im/babel/babel">gitter room</a> before creating an issue.
</p>

<p align="center">
  For documentation and website issues please visit the <a href="https://github.com/babel/babel.github.io">babel.github.io</a> repo.
</p>
